@@ -14,13 +14,13 @@ class ParsedMCON:
 class MCONParser:
     @staticmethod
     def parse_mcon(mcon: Optional[str]) -> Optional[ParsedMCON]:
-        if not mcon or not mcon.startswith('MCON++'):
+        if not mcon or not mcon.startswith("MCON++"):
             return None
 
-        mcon_parts = mcon.split('++', 4)
+        mcon_parts = mcon.split("++", 4)
         return ParsedMCON(
             account_id=UUID(mcon_parts[1]),
             resource_id=UUID(mcon_parts[2]),
             object_type=mcon_parts[3],
-            object_id=mcon_parts[4]
+            object_id=mcon_parts[4],
         )
