@@ -6,52 +6,43 @@ from pycarlo.common import http
 
 
 class S3UtilsTests(TestCase):
-
-    @patch('pycarlo.common.http.requests')
+    @patch("pycarlo.common.http.requests")
     def test_upload_bytes(self, mock_requests: Mock):
         # given
-        url = 'http://upload.com'
-        content = b'test'
+        url = "http://upload.com"
+        content = b"test"
 
         # when
         http.upload(url, content)
 
         # then
-        mock_requests.request.assert_called_once_with(
-            method='post',
-            url=url,
-            data=content
-        )
+        mock_requests.request.assert_called_once_with(method="post", url=url, data=content)
 
-    @patch('pycarlo.common.http.requests')
+    @patch("pycarlo.common.http.requests")
     def test_upload_dict(self, mock_requests: Mock):
         # given
-        url = 'http://upload.com'
-        content = {'foo': 'bar'}
+        url = "http://upload.com"
+        content = {"foo": "bar"}
 
         # when
         http.upload(url, content)
 
         # then
         mock_requests.request.assert_called_once_with(
-            method='post',
-            url=url,
-            data=json.dumps(content).encode('utf-8')
+            method="post", url=url, data=json.dumps(content).encode("utf-8")
         )
 
-    @patch('pycarlo.common.http.requests')
+    @patch("pycarlo.common.http.requests")
     def test_upload_str(self, mock_requests: Mock):
         # given
-        url = 'http://upload.com'
-        content = 'test'
-        method = 'put'
+        url = "http://upload.com"
+        content = "test"
+        method = "put"
 
         # when
         http.upload(url, content, method=method)
 
         # then
         mock_requests.request.assert_called_once_with(
-            method=method,
-            url=url,
-            data=content.encode('utf-8')
+            method=method, url=url, data=content.encode("utf-8")
         )
